@@ -3,7 +3,7 @@ from __future__ import unicode_literals, absolute_import
 """Top-level package for Dependency Parser."""
 
 __author__ = """Jannis Gebauer"""
-__email__ = 'ja.geb@me.com'
-__version__ = '0.1.0'
+__email__ = 'support@pyup.io'
+__version__ = '0.5.2'
 
-from .parser import parse
+from .parser import parse  # noqa
